@@ -19,13 +19,6 @@
 #define _GNUTLS_GCC_ATTR_DEPRECATED
 #endif
 
-#define gnutls_set_default_priority(x)					\
-  (gnutls_set_default_priority2 (x, GNUTLS_PRIORITIES_SECURITY_NORMAL), \
-   GNUTLS_E_SUCCESS)
-#define gnutls_set_default_export_priority(x)				\
-  (gnutls_set_default_priority2( x, GNUTLS_PRIORITIES_EXPORT),		\
-   GNUTLS_E_SUCCESS)
-
 #define gnutls_cipher_algorithm gnutls_cipher_algorithm_t
 #define gnutls_kx_algorithm gnutls_kx_algorithm_t
 #define gnutls_paramsype gnutls_paramsype_t
