@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2005 Free Software Foundation
+ * Copyright (C) 2005, 2007 Free Software Foundation
  *
- * Author: Nikos Mavroyanopoulos
+ * Author: Nikos Mavrogiannopoulos
  *
  * This file is part of GNUTLS.
  *
@@ -61,10 +61,10 @@ const mod_auth_st psk_auth_struct = {
  */
 int
 _gnutls_set_psk_session_key (gnutls_session_t session,
-			     gnutls_datum * dh_secret)
+			     gnutls_datum_t * dh_secret)
 {
-  gnutls_datum pwd_psk = { NULL, 0 };
-  gnutls_datum *ppsk;
+  gnutls_datum_t pwd_psk = { NULL, 0 };
+  gnutls_datum_t *ppsk;
   size_t dh_secret_size;
   int ret;
 
@@ -198,7 +198,7 @@ _gnutls_proc_psk_client_kx (gnutls_session_t session, opaque * data,
 {
   ssize_t data_size = _data_size;
   int ret;
-  gnutls_datum username;
+  gnutls_datum_t username;
   gnutls_psk_server_credentials_t cred;
   psk_auth_info_t info;
 
