@@ -394,14 +394,17 @@ _gnutls_auth_info_set (gnutls_session_t session,
 	   */
 	  if (gnutls_auth_get_type (session) != session->key->auth_info_type)
 	    {
+	    
+	      _gnutls_free_auth_info (session);
+	      
 	      session->key->auth_info =
-		gnutls_realloc_fast (session->key->auth_info, size);
+		calloc( 1, size);
 	      if (session->key->auth_info == NULL)
 		{
 		  gnutls_assert ();
 		  return GNUTLS_E_MEMORY_ERROR;
 		}
-	      memset (session->key->auth_info, 0, size);
+
 	      session->key->auth_info_type = type;
 	      session->key->auth_info_size = size;
 	    }
