@@ -91,7 +91,7 @@ _gnutls_encrypt (gnutls_session_t session, const opaque * headers,
       /* Here comp is allocated and must be 
        * freed.
        */
-      ret = _gnutls_m_plaintext2compressed (session, &comp, plain);
+      ret = _gnutls_m_plaintext2compressed (session, &comp, &plain);
       if (ret < 0)
 	{
 	  gnutls_assert ();
@@ -160,22 +160,30 @@ _gnutls_decrypt (gnutls_session_t session, opaque * ciphertext,
 
       gcomp.data = data;
       gcomp.size = ret;
-      ret = _gnutls_m_compressed2plaintext (session, &gtxt, gcomp);
+      ret = _gnutls_m_compressed2plaintext (session, &gtxt, &gcomp);
       if (ret < 0)
 	{
 	  return ret;
 	}
 
-      if (gtxt.size > max_data_size)
+      if (gtxt.size > MAX_RECORD_RECV_SIZE)
 	{
 	  gnutls_assert ();
 	  _gnutls_free_datum (&gtxt);
 	  /* This shouldn't have happen and
 	   * is a TLS fatal error.
 	   */
-	  return GNUTLS_E_INTERNAL_ERROR;
+	  return GNUTLS_E_DECOMPRESSION_FAILED;
 	}
 
+      /* This check is not really needed */
+      if (max_data_size < MAX_RECORD_RECV_SIZE) 
+        {
+          gnutls_assert();
+          _gnutls_free_datum (&gtxt);
+          return GNUTLS_E_INTERNAL_ERROR;
+        }
+
       memcpy (data, gtxt.data, gtxt.size);
       ret = gtxt.size;
 
@@ -445,6 +453,14 @@ _gnutls_ciphertext2compressed (gnutls_session_t session,
       return GNUTLS_E_INTERNAL_ERROR;
     }
 
+  if (ciphertext.size < (unsigned) blocksize + hash_size)
+    {
+      _gnutls_record_log
+	("REC[%x]: Short record length %d < %d + %d (under attack?)\n",
+	 session, ciphertext.size, blocksize, hash_size);
+      gnutls_assert ();
+      return GNUTLS_E_DECRYPTION_FAILED;
+    }
 
   /* actual decryption (inplace)
    */
@@ -496,9 +512,7 @@ _gnutls_ciphertext2compressed (gnutls_session_t session,
 
       pad = ciphertext.data[ciphertext.size - 1] + 1;	/* pad */
 
-      length = ciphertext.size - hash_size - pad;
-
-      if (pad > ciphertext.size - hash_size)
+      if ((int)pad > (int)ciphertext.size - hash_size)
 	{
 	  gnutls_assert ();
 	  /* We do not fail here. We check below for the
@@ -507,6 +521,8 @@ _gnutls_ciphertext2compressed (gnutls_session_t session,
 	  pad_failed = GNUTLS_E_DECRYPTION_FAILED;
 	}
 
+      length = ciphertext.size - hash_size - pad;
+
       /* Check the pading bytes (TLS 1.x)
        */
       if (ver >= GNUTLS_TLS1 && pad_failed == 0)
@@ -568,7 +584,7 @@ _gnutls_ciphertext2compressed (gnutls_session_t session,
   if (compress_size < length)
     {
       gnutls_assert ();
-      return GNUTLS_E_INTERNAL_ERROR;
+      return GNUTLS_E_DECOMPRESSION_FAILED;
     }
   memcpy (compress_data, ciphertext.data, length);
 
