@@ -531,7 +531,6 @@ gnutls_priority_init (gnutls_priority_t * priority_cache,
     }
 
   break_comma_list (darg, broken_list, &broken_list_size, MAX_ELEMENTS, ':');
-
   /* This is our default set of protocol version, certificate types and
    * compression methods.
    */
@@ -540,9 +539,14 @@ gnutls_priority_init (gnutls_priority_t * priority_cache,
       _set_priority (&(*priority_cache)->protocol, protocol_priority);
       _set_priority (&(*priority_cache)->compression, comp_priority);
       _set_priority (&(*priority_cache)->cert_type, cert_type_priority);
+      i = 0;
+    } 
+    else 
+    {
+      i = 1;
     }
 
-  for (i = 0; i < broken_list_size; i++)
+  for (; i < broken_list_size; i++)
     {
       if (strcasecmp (broken_list[i], "PERFORMANCE") == 0)
 	{
