@@ -187,9 +187,14 @@ void session::set_certificate_type_priority (const int *list)
 
 /* if you just want some defaults, use the following.
  */
-void session::set_default_priority(priority_flag flag)
+void session::set_priority(const char* prio, const char** err_pos)
 {
-    gnutls_set_default_priority2( this->s, flag);
+    RETWRAP(gnutls_priority_set_direct( this->s, prio, err_pos));
+}
+
+void session::set_priority(gnutls_priority_t p)
+{
+    RETWRAP(gnutls_priority_set( this->s, p));
 }
 
 gnutls_protocol_t session::get_protocol_version() const
