@@ -87,7 +87,7 @@ int _gnutls_x509_der_encode (ASN1_TYPE src, const char *src_name,
 
 int _gnutls_x509_export_int (ASN1_TYPE asn1_data,
 			     gnutls_x509_crt_fmt_t format, char *pem_header,
-			     int tmp_buf_size, unsigned char *output_data,
+			     unsigned char *output_data,
 			     size_t * output_data_size);
 
 int _gnutls_x509_read_value (ASN1_TYPE c, const char *root,
