@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003, 2004, 2005 Free Software Foundation
+ * Copyright (C) 2003, 2004, 2005, 2007 Free Software Foundation
  * Copyright (C) 2002 Andrew McDonald
  *
  * This file is part of GNUTLS.
@@ -29,7 +29,7 @@
 #include <gnutls_errors.h>
 
 /* compare hostname against certificate, taking account of wildcards
- * return 1 on success or 0 on error 
+ * return 1 on success or 0 on error
  */
 int
 _gnutls_hostname_compare (const char *certname, const char *hostname)
@@ -75,13 +75,13 @@ _gnutls_hostname_compare (const char *certname, const char *hostname)
   * @cert: should contain an gnutls_x509_crt_t structure
   * @hostname: A null terminated string that contains a DNS name
   *
-  * This function will check if the given certificate's subject matches
-  * the given hostname. This is a basic implementation of the matching 
-  * described in RFC2818 (HTTPS), which takes into account wildcards,
-  * and the subject alternative name PKIX extension.
-  *
-  * Returns non zero on success, and zero on failure.
+  * This function will check if the given certificate's subject
+  * matches the given hostname.  This is a basic implementation of the
+  * matching described in RFC2818 (HTTPS), which takes into account
+  * wildcards, and the DNSName/IPAddress subject alternative name PKIX
+  * extension.
   *
+  * Returns non zero for a successful match, and zero on failure.
   **/
 int
 gnutls_x509_crt_check_hostname (gnutls_x509_crt_t cert, const char *hostname)
@@ -111,9 +111,9 @@ gnutls_x509_crt_check_hostname (gnutls_x509_crt_t cert, const char *hostname)
     {
 
       dnsnamesize = sizeof (dnsname);
-      ret =
-	gnutls_x509_crt_get_subject_alt_name (cert, i,
-					      dnsname, &dnsnamesize, NULL);
+      ret = gnutls_x509_crt_get_subject_alt_name (cert, i,
+						  dnsname, &dnsnamesize,
+						  NULL);
 
       if (ret == GNUTLS_SAN_DNSNAME)
 	{
@@ -123,20 +123,29 @@ gnutls_x509_crt_check_hostname (gnutls_x509_crt_t cert, const char *hostname)
 	      return 1;
 	    }
 	}
-
+      else if (ret == GNUTLS_SAN_IPADDRESS)
+	{
+	  found_dnsname = 1; /* RFC 2818 is unclear whether the CN
+				should be compared for IP addresses
+				too, but we won't do it.  */
+	  if (_gnutls_hostname_compare (dnsname, hostname))
+	    {
+	      return 1;
+	    }
+	}
     }
 
   if (!found_dnsname)
     {
-      /* not got the necessary extension, use CN instead 
+      /* not got the necessary extension, use CN instead
        */
       dnsnamesize = sizeof (dnsname);
       if (gnutls_x509_crt_get_dn_by_oid (cert, OID_X520_COMMON_NAME, 0,
 					 0, dnsname, &dnsnamesize) < 0)
 	{
-	  /* got an error, can't find a name 
+	  /* got an error, can't find a name
 	   */
-	  return 1;
+	  return 0;
 	}
 
       if (_gnutls_hostname_compare (dnsname, hostname))
