@@ -82,7 +82,6 @@ _gnutls_map_cdk_rc (int rc)
     }
 }
 
-
 static unsigned long
 buftou32 (const uint8_t * buf)
 {
@@ -110,7 +109,10 @@ openpgp_pk_to_gnutls_cert (gnutls_cert * cert, cdk_pkt_pubkey_t pk)
 
   /* GnuTLS OpenPGP does not support ELG keys */
   if (is_ELG (pk->pubkey_algo))
-    return GNUTLS_E_UNWANTED_ALGORITHM;
+    {
+      gnutls_assert();
+      return GNUTLS_E_UNWANTED_ALGORITHM;
+    }
 
   algo = is_DSA (pk->pubkey_algo) ? GNUTLS_PK_DSA : GNUTLS_PK_RSA;
   cert->subject_pk_algorithm = algo;
@@ -282,8 +284,9 @@ _gnutls_openpgp_raw_key_to_gcert (gnutls_cert * cert,
   memset (cert, 0, sizeof *cert);
 
   rc = cdk_kbnode_read_from_mem (&knode, raw->data, raw->size);
-  if (!(rc = _gnutls_map_cdk_rc (rc)))
+  if (!(rc = _gnutls_map_cdk_rc (rc))) {
     pkt = cdk_kbnode_find_packet (knode, CDK_PKT_PUBLIC_KEY);
+  }
   if (!pkt)
     {
       gnutls_assert ();
